@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Author: XuMing <xuming624@qq.com>
+# Author: XuMing(xuming624@qq.com)
 # Brief: init
 
 from .config import language_model_path
@@ -13,7 +13,7 @@ corrector = Corrector()
 get_same_pinyin = corrector.get_same_pinyin
 get_same_stroke = corrector.get_same_stroke
 set_custom_confusion_dict = corrector.set_custom_confusion_dict
-set_custom_word = corrector.set_custom_word
+set_custom_word_freq = corrector.set_custom_word_freq
 set_language_model_path = corrector.set_language_model_path
 correct = corrector.correct
 ngram_score = corrector.ngram_score
